==> docx4j-openxml-objects-pml-8.1.6-sources.jar: org/pptx4j/com/microsoft/schemas/office/powerpoint/x2013/main/command/ObjectFactory.java <==

package org.pptx4j.com.microsoft.schemas.office.powerpoint.x2013.main.command;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the org.pptx4j.com.microsoft.schemas.office.powerpoint.x2013.main.command package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _CmAuthorMkLst_QNAME = new QName("http://schemas.microsoft.com/office/powerpoint/2013/main/command", "cmAuthorMkLst");
    private final static QName _CmMkLst_QNAME = new QName("http://schemas.microsoft.com/office/powerpoint/2013/main/command", "cmMkLst");
    private final static QName _DocMkLst_QNAME = new QName("http://schemas.microsoft.com/office/powerpoint/2013/main/command", "docMkLst");
    private final static QName _SldBaseMkLst_QNAME = new QName("http://schemas.microsoft.com/office/powerpoint/2013/main/command", "sldBaseMkLst");
    private final static QName _SldLayoutMkLst_QNAME = new QName("http://schemas.microsoft.com/office/powerpoint/2013/main/command", "sldLayoutMkLst");
    private final static QName _SldMasterMkLst_QNAME = new QName("http://schemas.microsoft.com/office/powerpoint/2013/main/command", "sldMasterMkLst");
    private final static QName _SldMkLst_QNAME = new QName("http://schemas.microsoft.com/office/powerpoint/2013/main/command", "sldMkLst");
    private final static QName _ChgInfo_QNAME = new QName("http://schemas.microsoft.com/office/powerpoint/2013/main/command", "chgInfo");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: org.pptx4j.com.microsoft.schemas.office.powerpoint.x2013.main.command
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link CTCommentAuthorMonikerList }
     * 
     */
    public CTCommentAuthorMonikerList createCTCommentAuthorMonikerList() {
        return new CTCommentAuthorMonikerList();
    }

    /**
     * Create an instance of {@link CTCommentMonikerList }
     * 
     */
    public CTCommentMonikerList createCTCommentMonikerList() {
        return new CTCommentMonikerList();
    }

    /**
     * Create an instance of {@link CTDocumentMonikerList }
     * 
     */
    public CTDocumentMonikerList createCTDocumentMonikerList() {
        return new CTDocumentMonikerList();
    }

    /**
     * Create an instance of {@link CTSlideBaseMonikerList }
     * 
     */
    public CTSlideBaseMonikerList createCTSlideBaseMonikerList() {
        return new CTSlideBaseMonikerList();
    }

    /**
     * Create an instance of {@link CTSlideLayoutMonikerList }
     * 
     */
    public CTSlideLayoutMonikerList createCTSlideLayoutMonikerList() {
        return new CTSlideLayoutMonikerList();
    }

    /**
     * Create an instance of {@link CTMainMasterMonikerList }
     * 
     */
    public CTMainMasterMonikerList createCTMainMasterMonikerList() {
        return new CTMainMasterMonikerList();
    }

    /**
     * Create an instance of {@link CTSlideMonikerList }
     * 
     */
    public CTSlideMonikerList createCTSlideMonikerList() {
        return new CTSlideMonikerList();
    }

    /**
     * Create an instance of {@link CTChangesInfo }
     * 
     */
    public CTChangesInfo createCTChangesInfo() {
        return new CTChangesInfo();
    }

    /**
     * Create an instance of {@link CTDocumentMoniker }
     * 
     */
    public CTDocumentMoniker createCTDocumentMoniker() {
        return new CTDocumentMoniker();
    }

    /**
     * Create an instance of {@link CTSlideMoniker }
     * 
     */
    public CTSlideMoniker createCTSlideMoniker() {
        return new CTSlideMoniker();
    }

    /**
     * Create an instance of {@link CTMainMasterMoniker }
     * 
     */
    public CTMainMasterMoniker createCTMainMasterMoniker() {
        return new CTMainMasterMoniker();
    }

    /**
     * Create an instance of {@link CTSlideLayoutMoniker }
     * 
     */
    public CTSlideLayoutMoniker createCTSlideLayoutMoniker() {
        return new CTSlideLayoutMoniker();
    }

    /**
     * Create an instance of {@link CTCommentMoniker }
     * 
     */
    public CTCommentMoniker createCTCommentMoniker() {
        return new CTCommentMoniker();
    }

    /**
     * Create an instance of {@link CTCommentAuthorMoniker }
     * 
     */
    public CTCommentAuthorMoniker createCTCommentAuthorMoniker() {
        return new CTCommentAuthorMoniker();
    }

    /**
     * Create an instance of {@link CTCommentChanges }
     * 
     */
    public CTCommentChanges createCTCommentChanges() {
        return new CTCommentChanges();
    }

    /**
     * Create an instance of {@link CTCommentAuthorChanges }
     * 
     */
    public CTCommentAuthorChanges createCTCommentAuthorChanges() {
        return new CTCommentAuthorChanges();
    }

    /**
     * Create an instance of {@link CTSlideChanges }
     * 
     */
    public CTSlideChanges createCTSlideChanges() {
        return new CTSlideChanges();
    }

    /**
     * Create an instance of {@link CTSlideLayoutChanges }
     * 
     */
    public CTSlideLayoutChanges createCTSlideLayoutChanges() {
        return new CTSlideLayoutChanges();
    }

    /**
     * Create an instance of {@link CTMainMasterChanges }
     * 
     */
    public CTMainMasterChanges createCTMainMasterChanges() {
        return new CTMainMasterChanges();
    }

    /**
     * Create an instance of {@link CTDocumentChanges }
     * 
     */
    public CTDocumentChanges createCTDocumentChanges() {
        return new CTDocumentChanges();
    }

    /**
     * Create an instance of {@link CTDocumentChangesList }
     * 
     */
    public CTDocumentChangesList createCTDocumentChangesList() {
        return new CTDocumentChangesList();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link CTCommentAuthorMonikerList }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://schemas.microsoft.com/office/powerpoint/2013/main/command", name = "cmAuthorMkLst")
    public JAXBElement<CTCommentAuthorMonikerList> createCmAuthorMkLst(CTCommentAuthorMonikerList value) {
        return new JAXBElement<CTCommentAuthorMonikerList>(_CmAuthorMkLst_QNAME, CTCommentAuthorMonikerList.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link CTCommentMonikerList }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://schemas.microsoft.com/office/powerpoint/2013/main/command", name = "cmMkLst")
    public JAXBElement<CTCommentMonikerList> createCmMkLst(CTCommentMonikerList value) {
        return new JAXBElement<CTCommentMonikerList>(_CmMkLst_QNAME, CTCommentMonikerList.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link CTDocumentMonikerList }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://schemas.microsoft.com/office/powerpoint/2013/main/command", name = "docMkLst")
    public JAXBElement<CTDocumentMonikerList> createDocMkLst(CTDocumentMonikerList value) {
        return new JAXBElement<CTDocumentMonikerList>(_DocMkLst_QNAME, CTDocumentMonikerList.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link CTSlideBaseMonikerList }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://schemas.microsoft.com/office/powerpoint/2013/main/command", name = "sldBaseMkLst")
    public JAXBElement<CTSlideBaseMonikerList> createSldBaseMkLst(CTSlideBaseMonikerList value) {
        return new JAXBElement<CTSlideBaseMonikerList>(_SldBaseMkLst_QNAME, CTSlideBaseMonikerList.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link CTSlideLayoutMonikerList }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://schemas.microsoft.com/office/powerpoint/2013/main/command", name = "sldLayoutMkLst")
    public JAXBElement<CTSlideLayoutMonikerList> createSldLayoutMkLst(CTSlideLayoutMonikerList value) {
        return new JAXBElement<CTSlideLayoutMonikerList>(_SldLayoutMkLst_QNAME, CTSlideLayoutMonikerList.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link CTMainMasterMonikerList }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://schemas.microsoft.com/office/powerpoint/2013/main/command", name = "sldMasterMkLst")
    public JAXBElement<CTMainMasterMonikerList> createSldMasterMkLst(CTMainMasterMonikerList value) {
        return new JAXBElement<CTMainMasterMonikerList>(_SldMasterMkLst_QNAME, CTMainMasterMonikerList.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link CTSlideMonikerList }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://schemas.microsoft.com/office/powerpoint/2013/main/command", name = "sldMkLst")
    public JAXBElement<CTSlideMonikerList> createSldMkLst(CTSlideMonikerList value) {
        return new JAXBElement<CTSlideMonikerList>(_SldMkLst_QNAME, CTSlideMonikerList.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link CTChangesInfo }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://schemas.microsoft.com/office/powerpoint/2013/main/command", name = "chgInfo")
    public JAXBElement<CTChangesInfo> createChgInfo(CTChangesInfo value) {
        return new JAXBElement<CTChangesInfo>(_ChgInfo_QNAME, CTChangesInfo.class, null, value);
    }

}

==> docx4j-openxml-objects-pml-11.5.6-sources.jar: org/pptx4j/com/microsoft/schemas/office/powerpoint/x2013/main/command/ObjectFactory.java <==

package org.pptx4j.com.microsoft.schemas.office.powerpoint.x2013.main.command;

import jakarta.xml.bind.JAXBElement;
import jakarta.xml.bind.annotation.XmlElementDecl;
import jakarta.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the org.pptx4j.com.microsoft.schemas.office.powerpoint.x2013.main.command package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _CmAuthorMkLst_QNAME = new QName("http://schemas.microsoft.com/office/powerpoint/2013/main/command", "cmAuthorMkLst");
    private final static QName _CmMkLst_QNAME = new QName("http://schemas.microsoft.com/office/powerpoint/2013/main/command", "cmMkLst");
    private final static QName _DocMkLst_QNAME = new QName("http://schemas.microsoft.com/office/powerpoint/2013/main/command", "docMkLst");
    private final static QName _SldBaseMkLst_QNAME = new QName("http://schemas.microsoft.com/office/powerpoint/2013/main/command", "sldBaseMkLst");
    private final static QName _SldLayoutMkLst_QNAME = new QName("http://schemas.microsoft.com/office/powerpoint/2013/main/command", "sldLayoutMkLst");
    private final static QName _SldMasterMkLst_QNAME = new QName("http://schemas.microsoft.com/office/powerpoint/2013/main/command", "sldMasterMkLst");
    private final static QName _SldMkLst_QNAME = new QName("http://schemas.microsoft.com/office/powerpoint/2013/main/command", "sldMkLst");
    private final static QName _ChgInfo_QNAME = new QName("http://schemas.microsoft.com/office/powerpoint/2013/main/command", "chgInfo");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: org.pptx4j.com.microsoft.schemas.office.powerpoint.x2013.main.command
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link CTCommentAuthorMonikerList }
     * 
     */
    public CTCommentAuthorMonikerList createCTCommentAuthorMonikerList() {
        return new CTCommentAuthorMonikerList();
    }

    /**
     * Create an instance of {@link CTCommentMonikerList }
     * 
     */
    public CTCommentMonikerList createCTCommentMonikerList() {
        return new CTCommentMonikerList();
    }

    /**
     * Create an instance of {@link CTDocumentMonikerList }
     * 
     */
    public CTDocumentMonikerList createCTDocumentMonikerList() {
        return new CTDocumentMonikerList();
    }

    /**
     * Create an instance of {@link CTSlideBaseMonikerList }
     * 
     */
    public CTSlideBaseMonikerList createCTSlideBaseMonikerList() {
        return new CTSlideBaseMonikerList();
    }

    /**
     * Create an instance of {@link CTSlideLayoutMonikerList }
     * 
     */
    public CTSlideLayoutMonikerList createCTSlideLayoutMonikerList() {
        return new CTSlideLayoutMonikerList();
    }

    /**
     * Create an instance of {@link CTMainMasterMonikerList }
     * 
     */
    public CTMainMasterMonikerList createCTMainMasterMonikerList() {
        return new CTMainMasterMonikerList();
    }

    /**
     * Create an instance of {@link CTSlideMonikerList }
     * 
     */
    public CTSlideMonikerList createCTSlideMonikerList() {
        return new CTSlideMonikerList();
    }

    /**
     * Create an instance of {@link CTChangesInfo }
     * 
     */
    public CTChangesInfo createCTChangesInfo() {
        return new CTChangesInfo();
    }

    /**
     * Create an instance of {@link CTDocumentMoniker }
     * 
     */
    public CTDocumentMoniker createCTDocumentMoniker() {
        return new CTDocumentMoniker();
    }

    /**
     * Create an instance of {@link CTSlideMoniker }
     * 
     */
    public CTSlideMoniker createCTSlideMoniker() {
        return new CTSlideMoniker();
    }

    /**
     * Create an instance of {@link CTMainMasterMoniker }
     * 
     */
    public CTMainMasterMoniker createCTMainMasterMoniker() {
        return new CTMainMasterMoniker();
    }

    /**
     * Create an instance of {@link CTSlideLayoutMoniker }
     * 
     */
    public CTSlideLayoutMoniker createCTSlideLayoutMoniker() {
        return new CTSlideLayoutMoniker();
    }

    /**
     * Create an instance of {@link CTCommentMoniker }
     * 
     */
    public CTCommentMoniker createCTCommentMoniker() {
        return new CTCommentMoniker();
    }

    /**
     * Create an instance of {@link CTCommentAuthorMoniker }
     * 
     */
    public CTCommentAuthorMoniker createCTCommentAuthorMoniker() {
        return new CTCommentAuthorMoniker();
    }

    /**
     * Create an instance of {@link CTCommentChanges }
     * 
     */
    public CTCommentChanges createCTCommentChanges() {
        return new CTCommentChanges();
    }

    /**
     * Create an instance of {@link CTCommentAuthorChanges }
     * 
     */
    public CTCommentAuthorChanges createCTCommentAuthorChanges() {
        return new CTCommentAuthorChanges();
    }

    /**
     * Create an instance of {@link CTSlideChanges }
     * 
     */
    public CTSlideChanges createCTSlideChanges() {
        return new CTSlideChanges();
    }

    /**
     * Create an instance of {@link CTSlideLayoutChanges }
     * 
     */
    public CTSlideLayoutChanges createCTSlideLayoutChanges() {
        return new CTSlideLayoutChanges();
    }

    /**
     * Create an instance of {@link CTMainMasterChanges }
     * 
     */
    public CTMainMasterChanges createCTMainMasterChanges() {
        return new CTMainMasterChanges();
    }

    /**
     * Create an instance of {@link CTDocumentChanges }
     * 
     */
    public CTDocumentChanges createCTDocumentChanges() {
        return new CTDocumentChanges();
    }

    /**
     * Create an instance of {@link CTDocumentChangesList }
     * 
     */
    public CTDocumentChangesList createCTDocumentChangesList() {
        return new CTDocumentChangesList();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link CTCommentAuthorMonikerList }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://schemas.microsoft.com/office/powerpoint/2013/main/command", name = "cmAuthorMkLst")
    public JAXBElement<CTCommentAuthorMonikerList> createCmAuthorMkLst(CTCommentAuthorMonikerList value) {
        return new JAXBElement<CTCommentAuthorMonikerList>(_CmAuthorMkLst_QNAME, CTCommentAuthorMonikerList.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link CTCommentMonikerList }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://schemas.microsoft.com/office/powerpoint/2013/main/command", name = "cmMkLst")
    public JAXBElement<CTCommentMonikerList> createCmMkLst(CTCommentMonikerList value) {
        return new JAXBElement<CTCommentMonikerList>(_CmMkLst_QNAME, CTCommentMonikerList.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link CTDocumentMonikerList }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://schemas.microsoft.com/office/powerpoint/2013/main/command", name = "docMkLst")
    public JAXBElement<CTDocumentMonikerList> createDocMkLst(CTDocumentMonikerList value) {
        return new JAXBElement<CTDocumentMonikerList>(_DocMkLst_QNAME, CTDocumentMonikerList.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link CTSlideBaseMonikerList }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://schemas.microsoft.com/office/powerpoint/2013/main/command", name = "sldBaseMkLst")
    public JAXBElement<CTSlideBaseMonikerList> createSldBaseMkLst(CTSlideBaseMonikerList value) {
        return new JAXBElement<CTSlideBaseMonikerList>(_SldBaseMkLst_QNAME, CTSlideBaseMonikerList.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link CTSlideLayoutMonikerList }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://schemas.microsoft.com/office/powerpoint/2013/main/command", name = "sldLayoutMkLst")
    public JAXBElement<CTSlideLayoutMonikerList> createSldLayoutMkLst(CTSlideLayoutMonikerList value) {
        return new JAXBElement<CTSlideLayoutMonikerList>(_SldLayoutMkLst_QNAME, CTSlideLayoutMonikerList.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link CTMainMasterMonikerList }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://schemas.microsoft.com/office/powerpoint/2013/main/command", name = "sldMasterMkLst")
    public JAXBElement<CTMainMasterMonikerList> createSldMasterMkLst(CTMainMasterMonikerList value) {
        return new JAXBElement<CTMainMasterMonikerList>(_SldMasterMkLst_QNAME, CTMainMasterMonikerList.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link CTSlideMonikerList }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://schemas.microsoft.com/office/powerpoint/2013/main/command", name = "sldMkLst")
    public JAXBElement<CTSlideMonikerList> createSldMkLst(CTSlideMonikerList value) {
        return new JAXBElement<CTSlideMonikerList>(_SldMkLst_QNAME, CTSlideMonikerList.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link CTChangesInfo }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://schemas.microsoft.com/office/powerpoint/2013/main/command", name = "chgInfo")
    public JAXBElement<CTChangesInfo> createChgInfo(CTChangesInfo value) {
        return new JAXBElement<CTChangesInfo>(_ChgInfo_QNAME, CTChangesInfo.class, null, value);
    }

}
